@@ -73,6 +73,6 @@ Construct a new L<Mojo::Pg::Transaction> object.
 
 =head1 SEE ALSO
 
-L<Mojo::Pg>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
+L<Mojo::Pg>, L<Mojolicious::Guides>, L<https://mojolicious.org>.
 
 =cut
